==> web-fw2_2_2.zip: web-fw2_2_2/j2src/weber/org/itscool/commons/request/SimpleHttpGeneralForm.java <==
package org.itscool.commons.request;

import org.itscool.commons.file.Log;
import org.itscool.commons.util.URLDecodeUtil;


/**
 * VvȌ`iContents-type=application)̃NGXgp[^͂NXł
 * @author KANO
 */
public class SimpleHttpGeneralForm extends HttpGeneralForm{
	private Log log = Log.getInstance();
	
    /**
     * NGXgꂽp[^͂܂<BR>
     * ͂ꂽp[^̓L[String^̒l̃yAŃXgɒǉ܂<BR>
     *  {̏ɂǂ܂<BR>
     * AbstractPostRequestNXdoDefaultParseData()gpĂ
     * @param buffer NGXg擾ꂽoCg`̃f[^
     * @param encode GR[fBO
     */
    protected void doParseData(byte[] buffer, String encode ) {
    	if(log.getLevel().equals(Log.DEBUG)){
        	log.debug("--------- recieved simple part request data ---- ");
    		log.debug("[@data]"+new String(buffer));
        }
    	String data = null;
        data = new String(buffer);
        //data = StringUtil.convEncode(buffer, "Shift_JIS");
        if( data == null || data.length() == 0) return;
        //System.out.println("[@data]" + data);
        
        String stack = data;
        
        //URLGR[hꂽHTTP{fB̏AXg[gēǂݏoB
        //́iOAljƂ`ȊÕf[^URLGR[hőĂ
        //ꍇɎgB
        //URLDecoder.decode()͓ʂȕgp application/x-www-form-urlencoded 
        //𕜍܂
        try{
        	//stack = URLDecoder.decode(data, encode);
        	stack = URLDecodeUtil.decode(data, encode);
        }catch(Exception e){
        	e.printStackTrace();
        }
        //String stack = StringUtil.convEncode(data, "Shift_JIS");
        
        while(stack.length() > 0){
            int kubunPos = stack.indexOf("&");
            if(kubunPos == -1 ) kubunPos = stack.length();
            String record = stack.substring(0, kubunPos);
            
            int eqPos = record.indexOf("=");
            String key = record.substring(0, eqPos);
            String value = record.substring(eqPos+1, record.length());
            this.addParameter(key, value);
            
//            System.out.print("[@key]"+key);
//            System.out.println(" [@data]"+value);
            if(log.getLevel().equals(Log.DEBUG)){
            	log.debug("[@key]"+key + " [@data]"+value);
            }
            stack = stack.substring(record.length(), stack.length());
            if(stack.indexOf("&")==0){
                stack = stack.substring(1, stack.length());
            }
        }
        //dL[ɂ镡p[^̃}[Ws
        margeParamsByDuplicateKey();
    }
    
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/weber/org/itscool/commons/request/SimpleHttpGeneralForm.java <==
package org.itscool.commons.request;

import org.itscool.commons.logging.SimpleLog;
import org.itscool.commons.util.URLDecodeUtil;


/**
 * VvȌ`iContents-type=application)̃NGXgp[^
 * AL[ƃp[^̈ꗗێNXł
 * @author KANO
 */
public class SimpleHttpGeneralForm extends HttpGeneralForm{

    /**
     * NGXgꂽp[^͂܂<BR>
     * ͂ꂽp[^̓L[String^̒l̃yAŃXgɒǉ܂<BR>
     *  {̏ɂǂ܂<BR>
     * AbstractPostRequestNXdoDefaultParseData()gpĂ
     * @param buffer NGXg擾ꂽoCg`̃f[^
     * @param encode GR[fBO
     */
    protected void doParseData(byte[] buffer, String encode ) {
    	if(log.getLevel().equals(SimpleLog.DEBUG)){
        	log.debug("--------- recieved simple part request data ---- ");
    		log.debug("[@data]"+new String(buffer));
        }
    	String data = null;
        data = new String(buffer);
        //data = StringUtil.convEncode(buffer, "Shift_JIS");
        if( data == null || data.length() == 0) return;
        //System.out.println("[@data]" + data);
        
        String stack = data;
        
        //URLGR[hꂽHTTP{fB̏AXg[gēǂݏoB
        //́iOAljƂ`ȊÕf[^URLGR[hőĂ
        //ꍇɎgB
        //URLDecoder.decode()͓ʂȕgp application/x-www-form-urlencoded 
        //𕜍܂
        try{
        	//stack = URLDecoder.decode(data, encode);
        	stack = URLDecodeUtil.decode(data, encode);
        }catch(Exception e){
        	e.printStackTrace();
        }
        //String stack = StringUtil.convEncode(data, "Shift_JIS");
        
        while(stack.length() > 0){
            int kubunPos = stack.indexOf("&");
            if(kubunPos == -1 ) kubunPos = stack.length();
            String record = stack.substring(0, kubunPos);
            
            int eqPos = record.indexOf("=");
            String key = record.substring(0, eqPos);
            String value = record.substring(eqPos+1, record.length());
            this.addParameter(key, value);
            
//            System.out.print("[@key]"+key);
//            System.out.println(" [@data]"+value);
            if(log.getLevel().equals(SimpleLog.DEBUG)){
            	log.debug("[@key]"+key + " [@data]"+value);
            }
            stack = stack.substring(record.length(), stack.length());
            if(stack.indexOf("&")==0){
                stack = stack.substring(1, stack.length());
            }
        }
        //dL[ɂ镡p[^̃}[Ws
        margeParamsByDuplicateKey();
    }
    
}
